{% load i18n %}

<div class="form-group clearfix">
    <label class="col-md-3 control-label" for="additionalInformation">{% trans "Additional Information" %}</label>
    <div class="col-md-9">
        <textarea class="form-control" id="additionalInformation" name="additionalInformation" rows="7"></textarea>
    </div>
</div>
