{% extends 'fleetpings/base.html' %}

{% load i18n %}
{% load static %}

{% block details %}
    <div class="aa-fleetpings row">
        <div class="col-md-6">
            {% include "fleetpings/form.html" %}
        </div>

        <div class="col-md-6">
            {% include 'fleetpings/ping.html' %}
        </div>

        <script type="application/javascript">
            var fleetpingsTranslations = {
                ping: {
                    success: '{% blocktrans context "%(usedPlatform)s is a variable that holds the current used platform. It can be either Slack or Discord. Do not translate it, just use it as it is." %}Success! Your ping has been sent to your {{ platformUsed }}.{% endblocktrans %}'
                },
                copyToClipboard: {
                    error: '{% trans "Error! Your ping was not copied to your clipboard. Maybe your browser doesn&apos;t support this feature." %}',
                    success: '{% blocktrans context "%(usedPlatform)s is a variable that holds the current used platform. It can be either Slack or Discord. Do not translate it, just use it as it is." %}Success! Your ping text has been copied to your clipboard. Now be a good FC and throw it in your {{ platformUsed }} so you actually get some people in fleet.{% endblocktrans %}',
                }
            };
        </script>
    </div>
{% endblock %}

{% block extra_javascript %}
    {% include 'bundles/jquery-datetimepicker-js.html' %}
    {% include 'bundles/clipboard-js.html' %}

    <script type="application/javascript" src="{% static 'fleetpings/js/fleetpings.min.js' %}"></script>
{% endblock %}

{% block extra_css %}
    {% include 'bundles/jquery-datetimepicker-css.html' %}
{% endblock %}

{% block extra_script %}
    $('#formupTime').datetimepicker({
        lang: '{{ LANGUAGE_CODE }}',
        maskInput: true,
        format: 'Y-m-d H:i',
        dayOfWeekStart: 1,
        step: 15
    });
{% endblock extra_script %}
