{% load static %}

{% if avoidCdn %}
    <script type="application/javascript" src="{% static 'fleetpings/libs/clipboard.js/2.0.6/clipboard.min.js' %}"></script>
{% else %}
    <script type="application/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/clipboard.js/2.0.6/clipboard.min.js"></script>
{% endif %}
